Welcome to the ARA documentation!
=================================
.. image:: _static/ara.png

Table of Contents
=================

.. toctree::
    :maxdepth: 2

    Installing ARA <installation>
    API configuration settings and preferences <api-configuration>
    API authentication and security <api-security>
    API endpoint documentation <api-documentation>
    API usage with built-in clients <api-usage>
    Architecture and workflows <architecture>

.. toctree::
   :maxdepth: 1

    ansible-role-ara-api <ansible-role-ara-api>
    ansible-role-ara-web <ansible-role-ara-web>
    ansible-role-ara-tests <ansible-role-ara-tests>
